@@ -8,10 +8,12 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-11-10'; # DATE
 our $DIST = 'App-SubtitleUtils'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 our @EXPORT_OK = qw(
-                       parse_srt
+                       srtparse
+                       srtcheck
+                       srtdump
                        srtcombinetext
                );
 
@@ -151,6 +153,13 @@ sub srtdump {
 $SPEC{srtcombinetext} = {
     v => 1.1,
     summary => 'Combine the text of two or more subtitle files (e.g. for different languages) into one',
+    description => <<'_',
+
+All the subtitle files must contain the same number of entries, with each entry
+containing the exact timestamps. The default is just to concatenate the text of
+each entry together, but you can customize each text using the `--eval` option.
+
+_
     args => {
         filenames => {
             schema => ['array*', of=>'filename*', min_len=>2],
@@ -164,9 +173,9 @@ $SPEC{srtcombinetext} = {
             cmdline_aliases => {e=>{}},
             description => <<'_',
 
-This code will be evaluated for every text of each entry of each SRT. `$_` will
-be set to the text, `$entry` to the entry hash, `$j` to the index of the files
-(starts at 0).
+This code will be evaluated for every text of each entry of each SRT, in the
+`main` package. `$_` will be set to the text, `$main::entry` to the entry hash,
+`$main::idx` to the index of the files (starts at 0).
 
 The code is expected to modify `$_`.
 
@@ -176,8 +185,14 @@ _
     examples => [
         {
             summary => 'Display English and French subtitles together',
+            description => <<'_',
+
+The English text is shown at the top, then a blank line (`<i></i>`), followed by
+the French text in italics.
+
+_
             src_plang => 'bash',
-            src => q|[[prog]] azur-et-asmar.en.srt azur-et-asmar.fr.srt -e 'if ($main::j) { chomp; $_ = "<i></i>\n<i>$_</i>\n" }'|,
+            src => q|[[prog]] azur-et-asmar.en.srt azur-et-asmar.fr.srt -e 'if ($main::idx) { chomp; $_ = "<i></i>\n<i>$_</i>\n" }'|,
             test => 0,
             'x.doc.show_result' => 0,
         },
@@ -261,7 +276,7 @@ App::SubtitleUtils - Utilities related to video subtitles
 
 =head1 VERSION
 
-This document describes version 0.008 of App::SubtitleUtils (from Perl distribution App-SubtitleUtils), released on 2022-11-10.
+This document describes version 0.009 of App::SubtitleUtils (from Perl distribution App-SubtitleUtils), released on 2022-11-10.
 
 =head1 DESCRIPTION
 
@@ -306,7 +321,7 @@ Usage:
 
 Check the properness of SRT file.
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -340,6 +355,10 @@ Usage:
 
 Combine the text of two or more subtitle files (e.g. for different languages) into one.
 
+All the subtitle files must contain the same number of entries, with each entry
+containing the exact timestamps. The default is just to concatenate the text of
+each entry together, but you can customize each text using the C<--eval> option.
+
 This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
@@ -350,9 +369,9 @@ Arguments ('*' denotes required arguments):
 
 Perl code to evaluate on every text.
 
-This code will be evaluated for every text of each entry of each SRT. C<$_> will
-be set to the text, C<$entry> to the entry hash, C<$j> to the index of the files
-(starts at 0).
+This code will be evaluated for every text of each entry of each SRT, in the
+C<main> package. C<$_> will be set to the text, C<$main::entry> to the entry hash,
+C<$main::idx> to the index of the files (starts at 0).
 
 The code is expected to modify C<$_>.
 
@@ -382,7 +401,7 @@ Usage:
 
  srtdump(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -416,7 +435,7 @@ Usage:
 
 Parse SRT and return data structure.
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
